@@ -156,7 +156,7 @@ static int mmap_transfer_src_ptr(snd_pcm_plugin_t *plugin, char **buffer, size_t
 }
 
 static ssize_t mmap_transfer(snd_pcm_plugin_t *plugin,
-			      char *src_ptr, size_t src_size,
+			      char *src_ptr UNUSED, size_t src_size UNUSED,
 			      char *dst_ptr, size_t dst_size)
 {
 	struct mmap_private_data *data;
@@ -174,10 +174,10 @@ static ssize_t mmap_transfer(snd_pcm_plugin_t *plugin,
 		return -EINVAL;
 	interleave = control->status.voices < 0;
 	if (interleave) {
-		if (dst_size != control->status.frag_size)
+		if (dst_size != (size_t)control->status.frag_size)
 			return -EINVAL;
 	} else {
-		if (dst_size != control->status.frag_size * control->status.voices)
+		if (dst_size != (size_t)control->status.frag_size * (size_t)control->status.voices)
 			return -EINVAL;
 	}
 	if (data->channel == SND_PCM_CHANNEL_PLAYBACK) {
@@ -266,7 +266,7 @@ static int mmap_action(snd_pcm_plugin_t *plugin, snd_pcm_plugin_action_t action)
 	return 0;	/* silenty ignore other actions */
 }
 
-static void mmap_free(snd_pcm_plugin_t *plugin, void *private_data)
+static void mmap_free(snd_pcm_plugin_t *plugin, void *private_data UNUSED)
 {
 	struct mmap_private_data *data;
 
